<!-- markdownlint-disable -->

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\drag_and_drop.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.drag_and_drop`




**Global Variables**
---------------
- **TYPE_CHECKING**
- **PYQT6**
- **PYQT5**
- **PYSIDE2**
- **PYSIDE6**

---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\drag_and_drop.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `accepts_file_drops`

```python
accepts_file_drops(extensions: 'str | [str]')
```

Decorator that enables drag-and-drop on a QWidget. Accepts a str or a list of strings of the valid file extensions. 


---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\drag_and_drop.py#L48"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `draggable`

```python
draggable(target)
```






---

<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\drag_and_drop.py#L91"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `PreviewDrag`




<a href="https://github.com/qtstrap/qtstrap/blob/master\qtstrap\utils\drag_and_drop.py#L92"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

### <kbd>method</kbd> `PreviewDrag.__init__`

```python
__init__(source, mimedata=None)
```











---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
